<?php
namespace App\Http\Controllers;
use App\Verifikasi;
use Illuminate\Http\Request;
use Yajra\Datatables\Html\Builder;
use Yajra\Datatables\Datatables;
use App\Food;
use App\Order;
use App\Paid;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Facades\File;
use Illuminate\Support\Facades\DB;
use App\Http\Requests\StoreFoodRequest;
use App\Http\Requests\UpdateFoodRequest;
use Illuminate\Database\Eloquent\ModelNotFoundException;
use App\BorrowLog;
use Illuminate\Support\Facades\Auth;
use App\Exceptions\FoodException;
use PDF;


class OrderController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */

    public function index(Request $request, Builder $htmlBuilder)
    {
        if(Auth::user()->id=='1'){
            $food = Food::all();
            return view('foods.index')->with(compact('food'));
        }
        else if(Auth::user()->id>='1'){
            $food = Food::all();
            return view('Manager.index')->with(compact('food'));
        }
        else
            return 'error';
    }
    public function save(Request $request)
    {
        $id=$request->get('id_food');
        $food = Food::findOrFail($id);
        $order = new Order();
        $order->id_food=$food->id;
        $order->name=Auth::user()->name;
        $order->status=0;
        $order->jumlah=$request->get('jumlah');
        $food->total_harga=$request->get('total_harga');
        $order->alamat=$request->get('alamat');
        $order->nomor_telepon=$request->get('nomor_telepon');
        $order->save();
        return view('Manager.lihat')->with(["food"=>$food,"order"=>$order]);
    }
    public function pesan($id)
    {
        $food = Food::findOrFail($id);

        return view('Order.pesan')->with(["food"=>$food]);
    }
    public function verification($id)
    {
        $input=Order::find($id);
        Verifikasi::create(['id_food'=>$input['id_food'],'name'=>$input['name'],'jumlah'=>$input['jumlah']]);
        Order::find($id)->delete();
        return redirect(url("/listFood"));
    }

    public function paid($id)
    {
        $input=Order::find($id);
        Paid::create(['id_food'=>$input['id_food'],'name'=>$input['name'],'jumlah'=>$input['jumlah']]);
        Order::find($id)->delete();
        return redirect(url("/listFood"));
    }

    public function destroy($id)
    {
        $order = Order::findOrFail($id);
        $order->delete();
        return redirect("listFoodCostumer");
    }

    public function delete($id)
    {
        $food = Food::findOrFail($id);
        $food->delete();
        return redirect("createFood");
    }
    public function create(Request $request)
    {
        return view('foods.tambah');
    }
    public function simpan(Request $request)
    {
        $food = new Food();
        $food->id=$request->get('id_food');
        $food->name=$request->get('name');
        $food->type=$request->get('type');
        $food->harga=$request->get('harga');
        $food->save();
        return redirect("createFood");
    }


    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */

    public function lihat()
    {
        return view('foods.lihat');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function borrow($id)
    {
        try {
            $food = Food::findOrFail($id);
            Auth::user()->borrow($food);
            Session::flash("flash_notification", [
                "level"=>"success",
                "message"=>"Berhasil memesan $food->title"
            ]);
        } catch (FoodException $e) {
            Session::flash("flash_notification", [
                "level"   => "danger",
                "message" => $e->getMessage()
            ]);
        } catch (ModelNotFoundException $e) {
            Session::flash("flash_notification", [
                "level"   => "danger",
                "message" => "Makanan tidak ditemukan."
            ]);
        }

        return redirect('/');
    }



    public function store(StoreFoodRequest $request)
    {

        $food = Food::create($request->except('cover'));
// isi field cover jika ada cover yang diupload
        if ($request->hasFile('cover')) {
// Mengambil file yang diupload
            $uploaded_cover = $request->file('cover');
// mengambil extension file
            $extension = $uploaded_cover->getClientOriginalExtension();
// membuat nama file random berikut extension
            $filename = md5(time()) . '.' . $extension;
// menyimpan cover ke folder public/img
            $destinationPath = public_path() . DIRECTORY_SEPARATOR . 'img';
            $uploaded_cover->move($destinationPath, $filename);
// mengisi field cover di food dengan filename yang baru dibuat
            $food->cover = $filename;
            $food->save();
        }
        Session::flash("flash_notification", [
            "level"=>"success",
            "message"=>"Berhasil menyimpan $food->title"
        ]);
        return redirect()->route('foods.index');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $food = Food::find($id);
        return view('foods.edit')->with(compact('food'));

    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(UpdateFoodRequest $request, $id)
    {

        $food = Food::find($id);
        if(!$food->update($request->all())) return redirect()->back();
        if ($request->hasFile('cover')) {
// menambil cover yang diupload berikut ekstensinya
            $filename = null;
            $uploaded_cover = $request->file('cover');
            $extension = $uploaded_cover->getClientOriginalExtension();
// membuat nama file random dengan extension
            $filename = md5(time()) . '.' . $extension;
            $destinationPath = public_path() . DIRECTORY_SEPARATOR . 'img';
// memindahkan file ke folder public/img
            $uploaded_cover->move($destinationPath, $filename);
// hapus cover lama, jika ada
            if ($food->cover) {
                $old_cover = $food->cover;
                $filepath = public_path() . DIRECTORY_SEPARATOR . 'img'
                    . DIRECTORY_SEPARATOR . $food->cover;
                try {
                    File::delete($filepath);
                } catch (FileNotFoundException $e) {
// File sudah dihapus/tidak ada
                }
            }
// ganti field cover dengan cover yang baru
            $food->cover = $filename;
            $food->save();
        }
        Session::flash("flash_notification", [
            "level"=>"success",
            "message"=>"Berhasil menyimpan $food->title"
        ]);
        return redirect()->route('foods.index');
    }



    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
//    public function destroy(Request $request, $id)
//    {
//        $food = Food::find($id);
//        $cover = $food->cover;
//        if(!$food->delete()) return redirect()->back();
//
//        // handle hapus buku via ajax
//        if ($request->ajax()) return response()->json(['id' => $id]);
//
//        // hapus cover lama, jika ada
//        if ($cover) {
//            $old_cover = $food->cover;
//            $filepath = public_path() . DIRECTORY_SEPARATOR . 'img'
//                . DIRECTORY_SEPARATOR . $food->cover;
//
//            try {
//                File::delete($filepath);
//            } catch (FileNotFoundException $e) {
//                // File sudah dihapus/tidak ada
//            }
//        }
//
//        Session::flash("flash_notification", [
//            "level"=>"success",
//            "message"=>"daftar berhasil dihapus"
//        ]);
//
//        return redirect()->route('foods.index');
//    }

    public function returnBack($food_id)
    {
        $borrowLog = BorrowLog::where('user_id', Auth::user()->id)
            ->where('food_id', $food_id)
            ->where('is_returned', 0)
            ->first();

        if ($borrowLog) {
            $borrowLog->is_returned = true;
            $borrowLog->save();

            Session::flash("flash_notification", [
                "level"   => "success",
                "message" => "Berhasil mengembalikan " . $borrowLog->food->title
            ]);
        }

        return redirect('/home');
    }
    public function export()
    {
        return view('foods.export');
    }

    public function exportPost(Request $request)
    {

        // validasi
        $this->validate($request, [
            'author_id'=>'required',
            'type'=>'required|in:pdf,xls'
        ], [
            'author_id.required'=>'Anda belum registrasi. silahkan registrasi terlebih dahulu.'
        ]);

        $foods = Food::whereIn('id', $request->get('author_id'))->get();

        $handler = 'export' . ucfirst($request->get('type'));
        return $this->$handler($foods);
    }

    private function exportPdf($foods)
    {
        $pdf = PDF::loadview('pdf.foods', compact('foods'));
        return $pdf->download('foods.pdf');
    }


}
