<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Pegawai as pegawai;
use App\Http\Requests\StorePegawaiRequest;
use App\Http\Requests\UpdatePegawaiRequest;
use Yajra\Datatables\Html\Builder;
use Yajra\Datatables\Datatables;

class pegawaiController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request, Builder $htmlBuilder)
    {
        if ($request->ajax()) {
            $pegawais = Pegawai::select(['id','name','alamat','umur','golongan']);
            return Datatables::of($pegawais)
                ->addColumn('stock', function($pegawai){
                    return $pegawai->stock;
                })
                ->addColumn('action', function($pegawai){
                    return view('datatable._action', [
                        'model'           => $pegawai,
                        'form_url'        => route('pegawai.destroy', $pegawai->id),
                        'edit_url'        => route('pegawai.edit', $pegawai->id),
                        'confirm_message' => 'Yakin ingin menghapus ' . $pegawai->name . '?',

                    ]);
                })->make(true);
        }

        $html = $htmlBuilder
            ->addColumn(['data' => 'name', 'name'=>'name', 'title'=>'name'])
            ->addColumn(['data' => 'alamat', 'name'=>'alamat', 'title'=>'alamat'])
            ->addColumn(['data' => 'umur', 'name'=>'umur', 'title'=>'umur'])
            ->addColumn(['data' => 'golongan', 'name'=>'golongan', 'title'=>'golongan'])
            ->addColumn(['data' => 'action', 'name'=>'action', 'title'=>'Action', 'orderable'=>false, 'searchable'=>false]);


        return view('authors.pegawai')->with(compact('html'));
    }




    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('authors.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(StorePegawaiRequest $request)
    {

        $pegawai = pegawai::create($request->except('cover'));
// isi field cover jika ada cover yang diupload
        if ($request->hasFile('cover')) {
// Mengambil file yang diupload
            $uploaded_cover = $request->file('cover');
// mengambil extension file
            $extension = $uploaded_cover->getClientOriginalExtension();
// membuat nama file random berikut extension
            $filename = md5(time()) . '.' . $extension;
// menyimpan cover ke folder public/img
            $destinationPath = public_path() . DIRECTORY_SEPARATOR . 'img';
            $uploaded_cover->move($destinationPath, $filename);
// mengisi field cover di pegawai dengan filename yang baru dibuat
            $pegawai->cover = $filename;
            $pegawai->save();
        }
        Session::flash("flash_notification", [
            "level"=>"success",
            "message"=>"Berhasil menyimpan $pegawai->name"
        ]);
        return redirect()->route('pegawai.index');
    }
    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }
}
